document.addEventListener('DOMContentLoaded', function() {
  const tabBar = document.getElementById('tab-bar');
  const tabContent = document.getElementById('tab-content');
  const addTabBtn = document.getElementById('add-tab-btn');
  const modal = document.getElementById('add-tab-modal');
  const newTabName = document.getElementById('new-tab-name');
  const newTabUrl = document.getElementById('new-tab-url');
  const confirmAddTab = document.getElementById('confirm-add-tab');
  const cancelAddTab = document.getElementById('cancel-add-tab');

  let tabs = [];
  let activeTabIndex = 0;

  function loadTabs() {
    chrome.storage.sync.get('lookerTabs', function(data) {
      if (data.lookerTabs) {
        tabs = data.lookerTabs;
        renderTabs();
        showTab(0);
      }
    });
  }

  function saveTabs() {
    chrome.storage.sync.set({ 'lookerTabs': tabs });
  }

  function renderTabs() {
    tabBar.innerHTML = '';
    tabBar.appendChild(addTabBtn);
    tabs.forEach((tab, index) => {
      const tabElement = document.createElement('button');
      tabElement.className = 'tab';
      tabElement.textContent = tab.name;
      tabElement.onclick = () => showTab(index);
      
      const closeBtn = document.createElement('span');
      closeBtn.textContent = ' ×';
      closeBtn.style.marginLeft = '5px';
      closeBtn.onclick = (e) => {
        e.stopPropagation();
        removeTab(index);
      };
      
      tabElement.appendChild(closeBtn);
      tabBar.appendChild(tabElement);
    });
  }

  function showTab(index) {
    activeTabIndex = index;
    document.querySelectorAll('.tab').forEach((tab, i) => {
      tab.classList.toggle('active', i === index);
    });
    tabContent.innerHTML = `<iframe src="${tabs[index].url}" title="${tabs[index].name}"></iframe>`;
  }

  function addTab(name, url) {
    tabs.push({ name, url });
    saveTabs();
    renderTabs();
    showTab(tabs.length - 1);
  }

  function removeTab(index) {
    tabs.splice(index, 1);
    saveTabs();
    renderTabs();
    if (tabs.length > 0) {
      showTab(Math.min(activeTabIndex, tabs.length - 1));
    } else {
      tabContent.innerHTML = '';
    }
  }

  addTabBtn.onclick = () => {
    modal.style.display = 'block';
  };

  confirmAddTab.onclick = () => {
    const name = newTabName.value.trim();
    const url = newTabUrl.value.trim();
    if (name && url) {
      addTab(name, url);
      modal.style.display = 'none';
      newTabName.value = '';
      newTabUrl.value = '';
    }
  };

  cancelAddTab.onclick = () => {
    modal.style.display = 'none';
    newTabName.value = '';
    newTabUrl.value = '';
  };

  window.onclick = (event) => {
    if (event.target === modal) {
      modal.style.display = 'none';
    }
  };

  loadTabs();
});